@@ -145,12 +145,10 @@ class CliOsduClient(OsduClient):
         Args:
             config_url_key (str): key in configuration for the base path
             url_extra_path (str): extra path to add to the base path
-            ok_status_codes (list, optional): Status codes for successful call. Defaults to [200].
+            ok_status_codes (list, optional): Optional status codes to check for successful call.
         """
         url = self.url_from_config(config_url_key, url_extra_path)
-        response = self.get(url)
-        if ok_status_codes is not None and response.status_code not in ok_status_codes:
-            raise HTTPError(response=response)
+        response = self.get(url, ok_status_codes)
         return response
 
     def cli_get_returning_json(
@@ -161,7 +159,7 @@ class CliOsduClient(OsduClient):
         Args:
             config_url_key (str): key in configuration for the base path
             url_extra_path (str): extra path to add to the base path
-            ok_status_codes (list, optional): accepted ok response codes. Defaults to None.
+            ok_status_codes (list, optional): Status codes indicating successful call. Defaults to [200].
         """
         url = self.url_from_config(config_url_key, url_extra_path)
         return self.get_returning_json(url, ok_status_codes)
@@ -192,34 +190,21 @@ class CliOsduClient(OsduClient):
         config_url_key: str,
         url_extra_path: str,
         ok_status_codes: list = None,
-    ):
+    ) -> requests.Response:
         """[summary]
 
         Args:
             config_url_key (str): key in configuration for the base path
             url_extra_path (str): extra path to add to the base path
             data (Union[str, dict]): json data as string or dict to send as the body
-            ok_status_codes (list, optional): Status codes indicating successful call. Defaults to [200].
+            ok_status_codes (list, optional): Optional status codes to check for successful call.
 
         Returns:
-            [type]: [description]
+            requests.Response: Response object from the HTTP call
         """
-        try:
-            url = self.url_from_config(config_url_key, url_extra_path)
-            self.delete(url, ok_status_codes)
-            return
-        except HTTPError as ex:
-            logger.error(MSG_HTTP_ERROR)
-            logger.error("Error (%s) - %s", ex.response.status_code, ex.response.reason)
-        except ValueError as ex:
-            logger.error(MSG_JSON_DECODE_ERROR)
-            logger.debug(ex)
-        except (NoOptionError, NoSectionError) as ex:
-            logger.warning(
-                "Configuration missing from config ('%s'). Run 'osdu config update'", ex.args[0]
-            )
-
-        sys.exit(1)
+        url = self.url_from_config(config_url_key, url_extra_path)
+        response = self.delete(url, ok_status_codes)
+        return response
 
     def cli_put(
         self,
@@ -233,12 +218,10 @@ class CliOsduClient(OsduClient):
         Args:
             config_url_key (str): key in configuration for the base path
             url_extra_path (str): extra path to add to the base path
-            ok_status_codes (list, optional): Status codes for successful call. Defaults to [200].
+            ok_status_codes (list, optional): Optional status codes to check for successful call.
         """
         url = self.url_from_config(config_url_key, url_extra_path)
-        response = self.put(url, data)
-        if ok_status_codes is not None and response.status_code not in ok_status_codes:
-            raise HTTPError(response=response)
+        response = self.put(url, data, ok_status_codes)
         return response
 
     def cli_put_returning_json(
@@ -254,7 +237,7 @@ class CliOsduClient(OsduClient):
             config_url_key (str): key in configuration for the base path
             url_extra_path (str): extra path to add to the base path
             data (Union[str, dict]): data to send
-            ok_status_codes (list, optional): accepted ok response codes. Defaults to None.
+            ok_status_codes (list, optional): accepted ok response codes. Defaults to [200].
 
         Returns:
             dict: returned json
