@@ -17,6 +17,6 @@ CRS_CATALOG_SERVICE_NAME = "CRS Catalog service"
 CRS_CATALOG_STATUS_PATH = "../_ah/readiness_check"
 CRS_CATALOG_SWAGGER_PATH = "../swagger-ui.html"
 
-CRS_CONVERTER_SERVICE_NAME = "CRS Catalog service"
+CRS_CONVERTER_SERVICE_NAME = "CRS Converter service"
 CRS_CONVERTER_STATUS_PATH = "../_ah/readiness_check"
 CRS_CONVERTER_SWAGGER_PATH = "../swagger-ui.html"
