@@ -27,6 +27,8 @@ CLI_CONFIG_DIR = os.path.expanduser(os.path.join("~", ".{0}".format(CLI_NAME)))
 CLI_ENV_VAR_PREFIX = CLI_NAME
 
 CONFIG_SERVER = "server"
+CONFIG_CRS_CATALOG_URL = "crs_catalog_url"
+CONFIG_CRS_CONVERTER_URL = "crs_converter_url"
 CONFIG_ENTITLEMENTS_URL = "entitlements_url"
 CONFIG_FILE_URL = "file_url"
 CONFIG_LEGAL_URL = "legal_url"
